Installation
============

This package must be installed like a standard third party Plone
product:

* add the package to the python environment used by the Zope instance.
* configure Zope to load the ``tno.euphorie`` zcml
* restart Zope
* install the package via the quick installer tool in the ZMI

If you do not already have Euphorie installed it will be installed
automatically.
